@@ -7,7 +7,7 @@ from simpleelf.elf_structs import ElfStructs
 from simpleelf.elf_builder import ElfBuilder
 from simpleelf import elf_consts
 
-from packers.utils import REGIONS_MAGIC, get_elf_from_code
+from packers.utils import CRASH_MAGIC, get_elf_from_code
 
 elf_structs = ElfStructs('>')
 
@@ -16,8 +16,8 @@ def unpack(fw, out):
 
     main_image = fw.read()
 
-    if REGIONS_MAGIC not in main_image:
-        logging.debug('didnt find REGIONS_MAGIC')
+    if CRASH_MAGIC not in main_image:
+        logging.debug('didnt find CRASH_MAGIC')
         return False
 
     e = get_elf_from_code(main_image)
